'use strict';
var app = angular.module('NotibeProject', [
    'ngAnimate',
    'ngCordova',
    'ionic',
    'config',
    //controllers
    'NotibeProject.controllers.begin',
    'NotibeProject.controllers.authentication',
    'NotibeProject.controllers.menu',
    'NotibeProject.controllers.stream',
    'NotibeProject.controllers.cdcgrid',
    'NotibeProject.controllers.notification',
    //services
    'NotibeProject.services.i18n',
    'NotibeProject.services.popup',
    'NotibeProject.services.toast',
    'NotibeProject.services.session',
    'NotibeProject.services.push',
    'NotibeProject.services.authentication',
    'NotibeProject.services.facebook',
    'NotibeProject.services.analytics',
    'NotibeProject.services.subscription',
    'NotibeProject.services.utils'
]);

app.directive('placehold', ['I18n', function (I18n) {
        return {
            restrict: 'A',
            require: 'ngModel',
            link: function (scope, element, attr, ctrl) {

                var value;

                var placehold = function () {
                    var i18nPlacehold = attr.placehold;
                    if (I18n.getText(attr.placehold) !== null) {
                        i18nPlacehold = I18n.getText(attr.placehold);
                    }
                    element.val(i18nPlacehold);
                };
                var unplacehold = function () {
                    element.val('');
                };

                scope.$watch(attr.ngModel, function (val) {
                    value = val || '';
                });

                element.bind('focus', function () {
                    if (value === '')
                        unplacehold();
                });

                element.bind('blur', function () {
                    if (element.val() === '')
                        placehold();
                });

                ctrl.$formatters.unshift(function (val) {
                    if (!val) {
                        placehold();
                        value = '';
                        var i18nPlacehold = attr.placehold;
                        if (I18n.getText(attr.placehold) !== null) {
                            i18nPlacehold = I18n.getText(attr.placehold);
                        }
                        return i18nPlacehold;
                    }
                    return val;
                });
            }
        };
    }]);

app.run(['$rootScope', '$ionicPlatform', '$cordovaDevice', '$state', '$timeout', 'Session', 'Authentication', 'I18n', 'Popup', 'Push', 'Analytics', 'Utils', '$cordovaPush',
    function ($rootScope, $ionicPlatform, $cordovaDevice, $state, $timeout, Session, Authentication, I18n, Popup, Push, Analytics, Utils, $cordovaPush) {
        $ionicPlatform.ready(function () {

            //set grade c for device to improce performance
            ionic.Platform.setGrade('c');
            console.log("Grade set to " + ionic.Platform.grade);

            //Try to set device data in session
            try {
                console.log("NOTIBE: Getting device info");
                //get and set uuid into session
                Session.sessionData.device.model = $cordovaDevice.getModel();
                console.log("NOTIBE: Model is: " + Session.sessionData.device.model);
                //get and set platform into session
                Session.sessionData.device.platform = $cordovaDevice.getPlatform();
                console.log("NOTIBE: Platform is: " + Session.sessionData.device.platform);
                //get and set uuid into session
                Session.sessionData.device.uuid = $cordovaDevice.getUUID();
                console.log("NOTIBE: UUID is: " + Session.sessionData.device.uuid);
            } catch (error) {
                //error during getting platform
                Session.sessionData.device.platform = "PC";
                console.log("NOTIBE: Platform is: PC");
            }

            //Splash for android
            if (Session.sessionData.device.platform === 'Android') {
                console.log("Showing SplashScreen Programmatically");
                $state.go("splash");
            }

            // Hide the accessory bar by default (remove this to show the accessory bar above the keyboard
            // for form inputs)
            if (window.cordova && window.cordova.plugins.Keyboard) {
                cordova.plugins.Keyboard.hideKeyboardAccessoryBar(true);
            }
            if (window.StatusBar) {
                console.log("Setting status bar options");
                // org.apache.cordova.statusbar required
                //StatusBar.styleDefault();
                StatusBar.overlaysWebView(false);
                StatusBar.backgroundColorByHexString("#298999");
            }

            //backbutton
            $ionicPlatform.registerBackButtonAction(function () {
                switch ($state.current.name) {
                    case 'begin':
                        if (Session.sessionData.device.platform !== 'iOS') {
                            navigator.app.exitApp();
                        }
                        break;
                    case 'login':
                        $state.go('begin');
                        break;
                    case 'recover':
                        $state.go('begin');
                        break;
                    case 'signup':
                        $state.go('begin');
                        break;
                    case 'menu':
                        //reload stream
                        try {
                            console.log("triggered stream refresh");
                            $rootScope.refreshStream();
                        } catch (error) {

                        }
                        $state.go('menu.stream');
                        break;
                    case 'menu.stream':
                        if (Session.sessionData.device.platform !== 'iOS') {
                            navigator.app.exitApp();
                        }
                        break;
                    case 'menu.notifications':
                        //reload stream
                        try {
                            console.log("triggered stream refresh");
                            $rootScope.refreshStream();
                        } catch (error) {

                        }
                        $state.go('menu.stream');
                        break;
                    case 'menu.cdcgrid':
                        //reload stream
                        try {
                            console.log("triggered stream refresh");
                            $rootScope.refreshStream();
                        } catch (error) {

                        }
                        $state.go('menu.stream');
                        break;
                    default:
                        if (Session.sessionData.device.platform !== 'iOS') {
                            navigator.app.exitApp();
                        }
                        break;
                }
            }, 100);

            //Try to get locale
            try {
                console.log("NOTIBE: Getting Locale");
                navigator.globalization.getLocaleName(
                        function (locale) {
                            //set locale
                            I18n.setCurrentLocale(locale.value);
                        },
                        function () {
                            //set locale null => try browser or english
                            I18n.setCurrentLocale(null);
                        }
                );
            } catch (error) {
                //set locale null => try browser or english
                I18n.setCurrentLocale(null);
            }

            //init analytics
            Analytics.init();

            try {
                //adbuddiz init
                adbuddiz.setAndroidPublisherKey("96ff1b3a-948e-4b5d-953f-b70c782c4f46");
                adbuddiz.setIOSPublisherKey("2bf3f393-da05-46f0-aa3d-741011904887");
                adbuddiz.cacheAds();
            } catch (error) {
                //nope
            }

            //adbuddiz show ad
            document.addEventListener('AB-didShowAd', function () {
                console.log("OPENED ADBUDDIZ INTERSTITIAL");
                Analytics.trackAction("AdBuddiz", "ShowAD");
            }, false);

            //adbuddiz hide ad
            document.addEventListener('AB-didHideAd', function () {
                console.log("CLOSED ADBUDDIZ INTERSTITIAL");
                Analytics.trackAction("AdBuddiz", "HideAD");
                //Try to turn on admob
                $rootScope.startAdmob();
            }, false);

            //adbuddiz error on ad
            document.addEventListener('AB-didFailToShowAd', function () {
                console.log("ERROR FOR ADBUDDIZ INTERSTITIAL");
                Analytics.trackAction("AdBuddiz", "FailToShow");
                //Try to turn on admob
                $rootScope.startAdmob();
            }, false);

            //adbuddiz clicked ad
            document.addEventListener('AB-didClick', function () {
                Analytics.trackAction("AdBuddiz", "ClickAD");
            }, false);

            $rootScope.startAdmob = function () {
                //Try to turn on admob
                try {
                    //set admob
                    var ads = {
                        android: {
                            banner: 'ca-app-pub-6639888934813816/6124791481'
                        },
                        ios: {
                            banner: 'ca-app-pub-6639888934813816/5081043482'
                        }
                    };
                    //start admob
                    if (admob) {
                        console.log("NOTIBE: Starting Google AdMob");
                        if (Session.sessionData.device.platform === 'Android') {
                            admob.createBannerView({publisherId: ads.android.banner});
                        }
                        if (Session.sessionData.device.platform === 'iOS') {
                            admob.createBannerView({publisherId: ads.ios.banner});
                        }
                    }
                } catch (error) {
                    //error in starting admob
                    console.log("NOTIBE: Error in starting Google AdMob - " + error.message);
                }
            };

            $rootScope.getPreferences = function () {
                //Try to get preferences
                try {
                    //get pushid
                    Session.sessionData.device.pushid = localStorage.getItem("pushid");
                    console.log("Pushid: " + Session.sessionData.device.pushid);
                    //get login details
                    var ltt = localStorage.getItem("ltt");
                    var un = localStorage.getItem("un");
                    if (ltt !== undefined && un !== undefined
                            && ltt !== null && un !== null
                            && ltt !== '' && un !== '') {
                        Session.loginType = 'token';
                        Authentication.loginLongTermToken(un, ltt,
                                function () {
                                    delete Session.loginType;
                                    //reload stream
                                    try {
                                        console.log("triggered stream refresh");
                                        $rootScope.refreshStream();
                                    } catch (error) {

                                    }
                                    $state.go("menu.stream", {}, {location: "replace"});
                                },
                                function () {
                                    $state.go("begin", {}, {location: "replace"});
                                });
                    } else {
                        $state.go("begin", {}, {location: "replace"});
                    }
                }
                catch (error) {
                    console.log("NOTIBE: Error while getting preferences - " + error.message);
                    $state.go("begin", {}, {location: "replace"});
                }
            };

            //iOS resume operations
            if (Session.sessionData.device.platform === 'iOS') {
                //Resume event
                document.addEventListener("resume", function () {
                    console.log("Resumed iOS Application");
                    Session.startLoading();
                    //Check service status
                    Utils.getStatus(
                            function () {
                                //if service is online, check iOS app version
                                Utils.isIOSAppVersionValid(
                                        function (valid) {
                                            Session.stopLoading();
                                            if (valid) {
                                                //get preferences and go on
                                                $rootScope.getPreferences();
                                            } else {
                                                console.log("App must be updated!");
                                                //if app not valid
                                                var updatePopup = Popup.confirm("Notibe", "app_to_update");
                                                updatePopup.then(function (res) {
                                                    if (res) {
                                                        window.open('http://itunes.apple.com/app/id980081985', '_system');
                                                    }
                                                    if (Session.sessionData.device.platform !== 'iOS') {
                                                        navigator.app.exitApp();
                                                    } else {
                                                        $state.go("splash");
                                                    }
                                                });
                                            }
                                        },
                                        function () {
                                            Session.stopLoading();
                                            console.log("App version validation not responding.");
                                            //if not responding
                                            var alertPopup = Popup.message("Notibe", "app_no_service");
                                            alertPopup.then(function (res) {
                                                if (Session.sessionData.device.platform !== 'iOS') {
                                                    navigator.app.exitApp();
                                                } else {
                                                    $state.go("splash");
                                                }
                                            });
                                        }
                                );
                            },
                            function () {
                                Session.stopLoading();
                                console.log("Service status not responding.");
                                //if not responding
                                var alertPopup = Popup.message("Notibe", "app_no_service");
                                alertPopup.then(function (res) {
                                    if (Session.sessionData.device.platform !== 'iOS') {
                                        navigator.app.exitApp();
                                    } else {
                                        $state.go("splash");
                                    }
                                });
                            }
                    );
                }, false);
            }

            //set onNotificationGCM event
            window.onNotificationGCM = function (e) {
                console.log("GCM Event: " + e.event);
                switch (e.event)
                {
                    case 'registered':
                        console.log("Received push id");
                        //if push id received and different from the previously retrieved one
                        if (e.regid.length > 0 && e.regid !== Session.sessionData.device.pushid) {
                            var pushendpointdata = {};
                            pushendpointdata.pushid = e.regid;
                            pushendpointdata.pushplatform = 'GCM';
                            localStorage.setItem("pushid", e.regid);
                            Session.sessionData.device.pushendpointdata = pushendpointdata;
                            Push.addpushendpoint(pushendpointdata, function (result, headers) {
                                //check for errors
                            });
                        }
                        break;
                    case 'message':
                        console.log("Received push message");
                        try {
                            console.log("triggered stream refresh");
                            $rootScope.refreshStream(
                                    function () {
                                        if (e.foreground) {
                                            console.log("foreground: " + e.payload.message);
                                            var confirmPopup = Popup.confirm("Notibe", e.payload.message);
                                            confirmPopup.then(function (res) {
                                                if (res) {
                                                    var mediaName = Session.sessionData.stream.list[0].userMedia.mediaName;
                                                    $rootScope.openMediaDetail(mediaName);
                                                    if ($state.current.name === 'menu.notifications') {
                                                        $rootScope.refreshNotifications(mediaName);
                                                    }
                                                }
                                            });
                                        } else {
                                            if (e.coldstart) {
                                                console.log("coldstart: " + e.payload.message);
                                                //TODO
                                            } else {
                                                console.log("background: " + e.payload.message);
                                                //TODO
                                            }
                                        }
                                    }
                            );
                        } catch (error) {
                            //if error do nothing
                        }
                        break;
                    case 'error':
                        console.log("Received push error");
                        break;
                    default:
                        console.log("Other push event");
                        break;
                }
            };

            //set onNotificationAPN event
            window.onNotificationAPN = function (event) {
                console.log("APN Event: " + event.alert);
                if (event.alert) {
                    navigator.notification.alert(notification.alert);
                }

                if (event.sound) {
                    var snd = new Media(event.sound);
                    snd.play();
                }

                if (event.badge) {
                    $cordovaPush.setBadgeNumber(event.badge).then(function (result) {
                        // Success
                    }, function (err) {
                        // Error
                    });
                }

//                //try to show message in app if open
//                try {
//                    $rootScope.refreshStream(function () {
//                        var confirmPopup = Popup.confirm("Notibe", notification.alert);
//                        confirmPopup.then(function (res) {
//                            if (res) {
//                                var mediaName = Session.sessionData.stream.list[0].userMedia.mediaName;
//                                $rootScope.openMediaDetail(mediaName);
//                                if ($state.current.name === 'menu.notifications') {
//                                    $rootScope.refreshNotifications(mediaName);
//                                }
//                            }
//                        });
//                    });
//                } catch (error) {
//                    //if error do nothing
//                }
            };

            //Check service status
            Utils.getStatus(
                    function () {
                        switch (Session.sessionData.device.platform) {
                            case 'Android':
                                //if service is online, check Android app version
                                Utils.isAndroidAppVersionValid(
                                        function (valid) {
                                            if (valid) {
                                                console.log("App version is valid!");
                                                //if app is valid, start it!
                                                var wait = Math.floor((Math.random() * 1000) + 1000);
                                                console.log("Splash will last " + wait + "ms.");
                                                $timeout(function () {
                                                    //show adbuddiz ad
                                                    adbuddiz.isReadyToShowAd(
                                                            function () {
                                                                console.log("AdBuddiz ready to show...");
                                                                adbuddiz.showAd();
                                                            },
                                                            function () {
                                                                console.log("AdBuddiz NO ADS to show... continue anyway.");
                                                                //Try to turn on admob
                                                                $rootScope.startAdmob();
                                                            }
                                                    );
                                                    //get preferences and go on
                                                    $rootScope.getPreferences();
                                                }, wait);
                                            } else {
                                                console.log("App must be updated!");
                                                //if app not valid
                                                var updatePopup = Popup.confirm("Notibe", "app_to_update");
                                                updatePopup.then(function (res) {
                                                    if (res) {
                                                        window.open('https://play.google.com/store/apps/details?id=com.md.NotibeProject', '_system');
                                                    }
                                                    if (Session.sessionData.device.platform !== 'iOS') {
                                                        navigator.app.exitApp();
                                                    }
                                                });
                                            }
                                        },
                                        function () {
                                            console.log("App version validation not responding.");
                                            //if not responding
                                            var alertPopup = Popup.message("Notibe", "app_no_service");
                                            alertPopup.then(function (res) {
                                                if (Session.sessionData.device.platform !== 'iOS') {
                                                    navigator.app.exitApp();
                                                }
                                            });
                                        }
                                );
                                break;
                            case 'iOS':
                                //if service is online, check iOS app version
                                Utils.isIOSAppVersionValid(
                                        function (valid) {
                                            if (valid) {
                                                console.log("Ios App version is valid! No Splashscreen!");
                                                //if app is valid, start it!
                                                //show adbuddiz ad
                                                adbuddiz.isReadyToShowAd(
                                                        function () {
                                                            console.log("AdBuddiz ready to show...");
                                                            adbuddiz.showAd();
                                                        },
                                                        function () {
                                                            console.log("AdBuddiz NO ADS to show... continue anyway.");
                                                            //Try to turn on admob
                                                            $rootScope.startAdmob();
                                                        }
                                                );
                                                //get preferences and go on
                                                $rootScope.getPreferences();
                                            } else {
                                                console.log("App must be updated!");
                                                //if app not valid
                                                var updatePopup = Popup.confirm("Notibe", "app_to_update");
                                                updatePopup.then(function (res) {
                                                    if (res) {
                                                        window.open('http://itunes.apple.com/app/id980081985', '_system');
                                                    }
                                                    if (Session.sessionData.device.platform !== 'iOS') {
                                                        navigator.app.exitApp();
                                                    }
                                                });
                                            }
                                        },
                                        function () {
                                            console.log("App version validation not responding.");
                                            //if not responding
                                            var alertPopup = Popup.message("Notibe", "app_no_service");
                                            alertPopup.then(function (res) {
                                                if (Session.sessionData.device.platform !== 'iOS') {
                                                    navigator.app.exitApp();
                                                }
                                            });
                                        }
                                );
                                break;
                            default:
                                var alertPopup = Popup.message("Notibe", "Platform not valid");
                                alertPopup.then(function (res) {
                                    if (Session.sessionData.device.platform !== 'iOS') {
                                        navigator.app.exitApp();
                                    }
                                });
                                break;
                        }
                    },
                    function () {
                        console.log("Service status not responding.");
                        //if not responding
                        var alertPopup = Popup.message("Notibe", "app_no_service");
                        alertPopup.then(function (res) {
                            if (Session.sessionData.device.platform !== 'iOS') {
                                navigator.app.exitApp();
                            }
                        });
                    }
            );
        });
    }]);

app.config(function ($stateProvider, $urlRouterProvider) {
    $stateProvider

            .state('empty', {
                url: '/empty',
                templateUrl: 'templates/empty.html',
                controller: 'BeginController'
            })

            .state('splash', {
                url: '/splash',
                templateUrl: 'templates/splash.html',
                controller: 'BeginController'
            })

            .state('begin', {
                url: '/begin',
                templateUrl: 'templates/begin.html',
                controller: 'BeginController'
            })

            .state('login', {
                url: '/login',
                templateUrl: 'templates/login.html',
                controller: 'AuthenticationController'
            })

            .state('recover', {
                url: '/recover',
                templateUrl: 'templates/recover.html',
                controller: 'AuthenticationController'
            })

            .state('recover_request', {
                url: '/recover_request',
                templateUrl: 'templates/recover_request.html',
                controller: 'AuthenticationController'
            })

            .state('recover_confirm', {
                url: '/recover_confirm',
                templateUrl: 'templates/recover_confirm.html',
                controller: 'AuthenticationController'
            })

            .state('signup', {
                url: '/signup',
                templateUrl: 'templates/signup.html',
                controller: 'AuthenticationController'
            })

            .state('menu', {
                url: '/menu',
                abstract: true,
                templateUrl: 'templates/menu.html',
                controller: 'MenuController'
            })

            .state('menu.stream', {
                url: '/stream',
                views: {
                    'menuContent': {
                        templateUrl: 'templates/stream.html',
                        controller: 'StreamController'
                    }
                }
            })

            .state('menu.notifications', {
                url: '/notifications',
                views: {
                    'menuContent': {
                        templateUrl: 'templates/notifications.html',
                        controller: 'NotificationController'
                    }
                }
            })

            .state('menu.cdcgrid', {
                url: '/cdcgrid',
                views: {
                    'menuContent': {
                        templateUrl: 'templates/cdcgrid.html',
                        controller: 'CdcGridController'
                    }
                }
            })

            .state('menu.terms', {
                url: '/terms',
                views: {
                    'menuContent': {
                        templateUrl: 'templates/terms.html',
                        controller: 'MenuController'
                    }
                }
            })

            ;

    // if none of the above states are matched, use this as the fallback
    $urlRouterProvider.otherwise('/empty');
});

