'use strict';
var menuController = angular.module('NotibeProject.controllers.menu', []);

menuController.controller('MenuController',
        ['$rootScope', '$scope', '$state', 'I18n', 'Analytics', 'Authentication', 'Session', 'Subscription', 'Facebook', 'Popup', 'Toast',
            function ($rootScope, $scope, $state, I18n, Analytics, Authentication, Session, Subscription, Facebook, Popup, Toast) {

                if (!Session.userIsLogged) {
                    $state.go('begin');
                }

                Analytics.trackView("Menu");

                $scope.user = function () {
                    return Session.currentUser;
                };

                $scope.userSubscriptions = function () {
                    return Session.currentUser.subscriptionsDictionary;
                };

                $scope.loggedUser = function () {
                    return Session.currentUser.nameToShow;
                };

                $scope.isLocalized = function () {
                    return I18n.isLocalized();
                };

                $scope.getText = function (key) {
                    return I18n.getText(key);
                };

                $scope.viewCdcList = function () {
                    Subscription.getContentCreators((Session.sessionData.contentCreators.page + 1), function () {
                        $state.go('menu.cdcgrid');
                    });
                };

                $scope.logOut = function () {
                    var messageLogout = "logout_message";
                    if (Session.sessionData.device.platform === 'iOS') {
                        messageLogout = "logout_message_ios";
                    }
                    var confirmPopup = Popup.confirm("logout_title", messageLogout);
                    confirmPopup.then(function (res) {
                        if (res) {
                            //track logout action
                            Analytics.trackAction("Menu", "Logout");
                            //logout service
                            Authentication.logout(function () {
                                console.log("user logged out");
                                //log out from facebook
                                if (localStorage.getItem("fbuser") === true) {
                                    Facebook.logout(function () {
                                        if (Session.sessionData.device.platform !== 'iOS') {
                                            navigator.app.exitApp();
                                        } else {
                                            $state.go("begin", {}, {});
                                        }
                                    });
                                    console.log("facebook logout");
                                } else {
                                    if (Session.sessionData.device.platform !== 'iOS') {
                                        navigator.app.exitApp();
                                    } else {
                                        $state.go("begin", {}, {});
                                    }
                                }
                            });
                        } else {
                            //track logout action
                            Analytics.trackAction("Menu", "Logout::Cancel");
                        }
                    });
                };

                $scope.unsubscribe = function (cc) {
                    Subscription.unsubscribeContentCreator(cc, function () {
                        //refresh grid cc
                        for (var k = 0; k < Session.sessionData.contentCreators.list.length; k++) {
                            var row = Session.sessionData.contentCreators.list[k];
                            for (var i = 0; i < row.length; i++) {
                                var col = row[i];
                                if (col.mediaName === cc.mediaName) {
                                    Session.sessionData.contentCreators.list[k][i].subscribed = false;
                                }
                            }
                        }
                        try {
                            Toast.shortCenter("toast_unsubscribed");
                        } catch (e) {
                            //nothing
                        }
                        //init session stream
                        Session.sessionData.stream = {
                            page: -1,
                            has_next: true,
                            list: []
                        };
                        //reload stream
                        try {
                            console.log("triggered stream refresh");
                            $rootScope.refreshStream();
                        } catch (error) {

                        }
                    });
                };

                $scope.toggleNormalPriority = function (subscription) {
                    var mediaName = subscription.mediaPlatform.mediaName;
                    Subscription.toggleNormalPriority(mediaName, function () {
                        if (subscription.npEnabled) {
                            Toast.shortCenter("toast_np_enabled");
                        } else {
                            Toast.shortCenter("toast_np_disabled");
                        }
                    });
                };

                $scope.viewTerms = function () {
                    $state.go('menu.terms');
                };

                $scope.viewStream = function () {
                    //reload stream
                    try {
                        console.log("triggered stream refresh");
                        $rootScope.refreshStream();
                    } catch (error) {

                    }
                    $state.go("menu.stream", {}, {});
                };

                $scope.isItalian = function () {
                    return I18n.getCurrentLanguage() === 'it';
                };
            }]);
