'use strict';
var notificationController = angular.module('NotibeProject.controllers.notification', []);

notificationController.controller('NotificationController',
        ['$rootScope', '$scope', '$state', 'I18n', 'Analytics', 'Session', 'Subscription', 'Toast',
            function ($rootScope, $scope, $state, I18n, Analytics, Session, Subscription, Toast) {

                Analytics.trackView("Notifications");

                $scope.isLocalized = function () {
                    return I18n.isLocalized();
                };

                $scope.getText = function (key) {
                    return I18n.getText(key);
                };

                $scope.goBack = function () {
                    try {
                        console.log("triggered stream refresh");
                        $rootScope.refreshStream();
                    } catch (error) {

                    }
                    $state.go('menu.stream');
                };

                $scope.doRefresh = function (mediaName) {
                    $rootScope.refreshNotifications(mediaName);
                };

                $rootScope.refreshNotifications = function (mediaName, successHandler) {
                    Session.sessionData.mediaNotifications[mediaName] = {
                        page: -1,
                        has_next: true,
                        list: []
                    };
                    Subscription.getNotificationsForMediaName((Session.sessionData.mediaNotifications[mediaName].page + 1), mediaName, function () {
                        var length = Session.sessionData.mediaNotifications[mediaName].list.length;
                        if (length > 0) {
                            Session.sessionData.firstNotification = Session.sessionData.mediaNotifications[mediaName].list[0];
                            Session.sessionData.previousNotifications = Session.sessionData.mediaNotifications[mediaName].list.slice(1, length);
                        }
                        $scope.firstNotification = Session.sessionData.firstNotification;
                        $scope.previousNotifications = Session.sessionData.previousNotifications;
                        // Stop the ion-refresher from spinning
                        $scope.$broadcast('scroll.refreshComplete');
                        //go back to caller
                        successHandler();
                    });
                };

                $scope.openInBrowser = function (notification) {
                    var url = notification.contentUrl;
                    var mediaName = notification.userMediaPlatform.mediaName;
                    var notificationId = notification.id;
                    Analytics.trackAction("Notification", "OpenContent::" + mediaName + "::" + notificationId);
                    if (url !== undefined && url !== null && url !== "") {
                        if (url.indexOf("facebook") > 0) {
                            try {
                                window.open("fb://facewebmodal/f?href=" + url, "_system");
                                Toast.shortCenter("toast_open_fb");
                            } catch (error) {
                                window.open(url, '_system');
                                Toast.shortCenter("toast_open");
                            }
                        } else if (url.indexOf("youtube") > 0 || url.indexOf("youtu.be") > 0) {
                            window.open(url, '_system');
                            Toast.shortCenter("toast_open_yt");
                        } else if (url.indexOf("plus.google") > 0) {
                            window.open(url, '_system');
                            Toast.shortCenter("toast_open");
                        } else {
                            window.open(url, '_system');
                            Toast.shortCenter("toast_open");
                        }
                    }
                };

                $scope.isHighPriority = function (notification) {
                    return notification.priority === "HIGH";
                };

                $scope.formatDate = function (aUTCDate) {
                    return I18n.formatDate(aUTCDate);
                };

                $scope.share = function (notification) {
                    var mediaName = notification.userMediaPlatform.mediaName;
                    var notificationId = notification.id;
                    Analytics.trackAction("Notification", "ShareContent::" + mediaName + "::" + notificationId);
                    Session.startLoading();
                    window.plugins.socialsharing.shareViaFacebookWithPasteMessageHint(
                            notification.text,
                            null /* img */,
                            notification.contentUrl /* url */,
                            I18n.getText("share_from_clipboard"),
                            function () {
                                console.log('share ok');
                                Session.stopLoading();
                            },
                            function (errormsg) {
                                console.log('share not ok');
                                Session.stopLoading();
                            }
                    );
                };

                $scope.email = function (notification) {
                    var mediaName = notification.userMediaPlatform.mediaName;
                    var notificationId = notification.id;
                    Analytics.trackAction("Notification", "EmailContent::" + mediaName + "::" + notificationId);
                    Session.startLoading();
                    window.plugins.socialsharing.shareViaEmail(
                            I18n.getText("share_mail_notify") + ": " + notification.text + "\n\nLink: " + notification.contentUrl,
                            I18n.getText("share_mail_from") + notification.userMediaPlatform.mediaName,
                            null, // TO: must be null or an array
                            null, // CC: must be null or an array
                            null, // BCC: must be null or an array
                            [notification.userMediaPlatform.mediaImageUrl], // FILES: can be null, a string, or an array
                            function () {
                                Session.stopLoading();
                            }, // called when sharing worked
                            function () {
                                Session.stopLoading();
                            }// called when sh*t hits the fan
                    );
                };

                $scope.copyToClipboard = function (value) {
                    Analytics.trackAction("Notification", "CopyLink::" + value);
                    cordova.plugins.clipboard.copy(value);
                    Toast.shortCenter("toast_copy");
                };

                $scope.loadMore = function (mediaName) {
                    Subscription.getNotificationsForMediaName((Session.sessionData.mediaNotifications[mediaName].page + 1), mediaName, function () {
                        var length = Session.sessionData.mediaNotifications[mediaName].list.length;
                        if (length > 0) {
                            Session.sessionData.firstNotification = Session.sessionData.mediaNotifications[mediaName].list[0];
                            Session.sessionData.previousNotifications = Session.sessionData.mediaNotifications[mediaName].list.slice(1, length);
                            $scope.firstNotification = Session.sessionData.firstNotification;
                            $scope.previousNotifications = Session.sessionData.previousNotifications;
                        }
                    });
                };

                $scope.areThereMore = function (mediaName) {
                    return Session.sessionData.mediaNotifications[mediaName].has_next;
                };

                $scope.openNotification = function (notification) {
                    $(".pnbc").hide();
                    $(".pnbo").show();
                    $(".pnb").hide();
                    $("#notification_" + notification.id).show();
                    $("#open_" + notification.id).hide();
                    $("#close_" + notification.id).show();
                };

                $scope.closeNotification = function (notification) {
                    $("#notification_" + notification.id).hide();
                    $("#close_" + notification.id).hide();
                    $("#open_" + notification.id).show();
                };

                $scope.firstNotification = Session.sessionData.firstNotification;

                $scope.previousNotifications = Session.sessionData.previousNotifications;
            }]);
