'use strict';
var streamController = angular.module('NotibeProject.controllers.stream', []);

streamController.controller('StreamController',
        ['$rootScope', '$scope', '$state', 'I18n', 'Analytics', 'Session', 'Subscription', 'Popup', '$ionicScrollDelegate',
            function ($rootScope, $scope, $state, I18n, Analytics, Session, Subscription, Popup, $ionicScrollDelegate) {

                Analytics.trackView("Stream");

                $scope.loadStream = function () {
                    if (Session.sessionData.stream.has_next) {
                        Subscription.getStream((Session.sessionData.stream.page + 1), function () {
                            //SUCCESS LOAD
                            $scope.ccStream = Session.sessionData.stream.list;
                        });
                    }
                };

                $scope.doRefresh = function () {
                    $rootScope.refreshStream();
                };

                $rootScope.refreshStream = function (successHandler) {
                    //init session stream
                    Session.sessionData.stream = {
                        page: -1,
                        has_next: true,
                        list: []
                    };
                    //reload stream
                    if (Session.sessionData.stream.has_next) {
                        Subscription.getStream((Session.sessionData.stream.page + 1), function () {
                            //SUCCESS LOAD
                            $scope.ccStream = Session.sessionData.stream.list;
                            // Stop the ion-refresher from spinning
                            $scope.$broadcast('scroll.refreshComplete');
                            //scroll to top
                            $ionicScrollDelegate.scrollTop();
                            try {
                                //go back to caller
                                successHandler();
                            } catch (error) {
                                //nope
                            }
                        });
                    }
                };

                //load stream
                if (Session.sessionData.stream.list.length === 0) {
                    $scope.loadStream();
                }

                $scope.isLocalized = function () {
                    return I18n.isLocalized();
                };

                $scope.getText = function (key) {
                    return I18n.getText(key);
                };

                $scope.shortenText = function (text) {
                    return text.substr(0, 40) + "...";
                };

                $scope.formatDate = function (aUTCDate) {
                    return I18n.formatDate(aUTCDate);
                };

                $scope.isRecent = function (aUTCDate) {
                    var now = new Date();
                    aUTCDate = aUTCDate.replace(' ', 'T') + 'Z';
                    var notificationDate = new Date(aUTCDate);
                    var timeDiff = Math.abs(now.getTime() - notificationDate.getTime());
                    var diffHours = Math.ceil(timeDiff / (1000 * 3600));
                    var isRecent = (diffHours <= 2) ? true : false;
                    //console.log("Recent notification: " + isRecent);
                    return isRecent;
                };

                $scope.viewCdcList = function () {
                    Subscription.getContentCreators((Session.sessionData.contentCreators.page + 1), function () {
                        $state.go('menu.cdcgrid');
                    });
                };

                $scope.ccDetail = function (cc) {
                    $rootScope.openMediaDetail(cc.userMedia.mediaName);
                };

                $rootScope.openMediaDetail = function (mediaName) {
                    Session.sessionData.mediaNotifications[mediaName] = {
                        page: -1,
                        has_next: true,
                        list: []
                    };
                    Subscription.getNotificationsForMediaName((Session.sessionData.mediaNotifications[mediaName].page + 1), mediaName, function () {
                        var length = Session.sessionData.mediaNotifications[mediaName].list.length;
                        if (length > 0) {
                            Session.sessionData.firstNotification = Session.sessionData.mediaNotifications[mediaName].list[0];
                            Session.sessionData.previousNotifications = Session.sessionData.mediaNotifications[mediaName].list.slice(1, length);
                        }
                        $state.go('menu.notifications', {}, {reload: true});
                    });
                };

                $scope.viewStream = function () {
                    Session.sessionData.notification = {};
                    //reload stream
                    try {
                        $rootScope.refreshStream();
                    } catch (error) {

                    }
                    $state.go("menu.stream", {}, {location: "replace"});
                };

                $scope.loadMore = function () {
                    //reload stream
                    if (Session.sessionData.stream.has_next) {
                        Subscription.getStream((Session.sessionData.stream.page + 1), function () {
                            //SUCCESS LOAD
                            $scope.ccStream = Session.sessionData.stream.list;
                            $ionicScrollDelegate.resize();
                        });
                    }
                };

                $scope.areThereMore = function () {
                    return Session.sessionData.stream.has_next;
                };

                $scope.ccStream = Session.sessionData.stream.list;
            }]);
