'use strict';
var loginService = angular.module('NotibeProject.services.authentication', []);
loginService.config(['$httpProvider', function ($httpProvider) {
        $httpProvider.defaults.withCredentials = false;
        $httpProvider.defaults.useXDomain = true;
    }]);
loginService.factory('Authentication', ['$http', '$state', 'Session', 'Push', 'Analytics', 'Popup', 'I18n', function ($http, $state, Session, Push, Analytics, Popup, I18n) {

        var registerPush = function () {
            console.log("registering push service");
            //register the pushid
            Push.registerPush();
        };

        function setUserDataToSession(headers, data) {
            Session.currentUser.roles = [];
            for (var idx in data.resultMap.user_roles) {
                Session.currentUser.roles.push(data.resultMap.user_roles[idx].authority.role);
            }
            //check if the only role is USER (only users can use mobile app)
            if (Session.currentUser.roles.length > 1 || Session.currentUser.roles.indexOf("ROLE_USER") === -1) {
                //user invalid
                return false;
            }
            Session.currentUser.t = headers().spring_security_remember_me_cookie;
            Session.currentUser.id = data.resultMap.id;
            Session.currentUser.firstname = data.resultMap.first_name;
            Session.currentUser.lastname = data.resultMap.last_name;
            Session.currentUser.username = data.resultMap.username;
            Session.currentUser.ltt = data.resultMap.long_term_token;
            Session.currentUser.subscriptionsDictionary = new Object();
            for (var i in data.resultMap.subscriptions) {
                var subscription = data.resultMap.subscriptions[i];
                Session.currentUser.subscriptionsDictionary[subscription.mediaPlatform.mediaName] = subscription;
            }
            //set computed data
            var loggedUser = "";
            if (Session.currentUser.firstname) {
                loggedUser += Session.currentUser.firstname + " ";
            }
            if (Session.currentUser.lastname) {
                loggedUser += Session.currentUser.lastname;
            }
            Session.currentUser.nameToShow = loggedUser;
//            //log user
//            console.log("Logged user...");
//            for (var i in Session.currentUser) {
//                console.log(i + ": " + Session.currentUser[i]);
//            }
            //user valid
            try {
                localStorage.setItem("un", Session.currentUser.username);
                localStorage.setItem("ltt", Session.currentUser.ltt);
//                //debug
//                var ltt = localStorage.getItem("ltt");
//                console.log("set ltt: " + ltt);
//                var un = localStorage.getItem("un");
//                console.log("set un: " + un);
            } catch (error) {
                console.log("NOTIBE: Error adding localStorage");
            }
            return true;
        }

        return {
            login: function (loginData, successHandler, failureHandler) {
                //start loading
                Session.startLoading();
                //do call
                $http({
                    method: 'GET',
                    url: Session.baseUrl + Session.servicePath + '/login',
                    headers: {
                        securityToken: Session.securityToken
                    },
                    params: {
                        logintype: Session.loginType,
                        username: loginData.email,
                        password: loginData.password
                    }
                }).success(function (data, status, headers, config) {
                    //check exit code
                    switch (data.exitCode) {
                        case 0:
                            break;
                        case 26:
                            //stop loading
                            Session.stopLoading();
                            //popup error
                            Popup.error("user_not_found");
                            return;
                        case 27:
                            //stop loading
                            Session.stopLoading();
                            //popup error
                            Popup.error("wrong_password");
                            return;
                        default:
                            //stop loading
                            Session.stopLoading();
                            //popup error
                            Popup.error("user_not_found");
                            $state.go('begin');
                            return;
                    }
                    //set session user
                    var userValid = setUserDataToSession(headers, data);
                    //check if set was ok
                    if (!userValid) {
                        //stop loading
                        Session.stopLoading();
                        //popup error
                        Popup.error("user_invalid");
                        $state.go('begin');
                        return;
                    }
                    Analytics.trackAction("Login", "User" + Session.currentUser.id);
                    //track userid
                    Analytics.setUser(Session.currentUser.id);
                    //register push id
                    registerPush();
                    //stop loading
                    Session.stopLoading();
                    //return to caller
                    successHandler();
                }).error(function (data, status, headers, config) {
                    //error
                    console.log("Error calling /login for username and password.");
                    //stop loading
                    Session.stopLoading();
                    //return to caller
                    failureHandler();
                });
            },
            loginFacebook: function (token, successHandler, failureHandler) {
                //start loading
                Session.startLoading();
                //do call
                $http({
                    method: 'GET',
                    url: Session.baseUrl + Session.servicePath + '/login',
                    headers: {
                        securityToken: Session.securityToken
                    },
                    params: {
                        logintype: Session.loginType,
                        fbtoken: token
                    }
                }).success(function (data, status, headers, config) {
                    //check exit code
                    switch (data.exitCode) {
                        case 0:
                            break;
                        case 26:
                            //stop loading
                            Session.stopLoading();
                            //popup error
                            Popup.error("user_not_found");
                            return;
                        case 27:
                            //stop loading
                            Session.stopLoading();
                            //popup error
                            Popup.error("wrong_password");
                            return;
                        default:
                            //stop loading
                            Session.stopLoading();
                            //popup error
                            Popup.error("user_not_found");
                            $state.go('begin');
                            return;
                    }
                    //set session user
                    var userValid = setUserDataToSession(headers, data);
                    //check if set was ok
                    if (!userValid) {
                        //stop loading
                        Session.stopLoading();
                        //popup error
                        Popup.error("user_invalid");
                        $state.go('begin');
                        return;
                    }
                    Analytics.trackAction("LoginFacebook", "User" + Session.currentUser.id);
                    localStorage.setItem("fbuser", true);
                    //track userid
                    Analytics.setUser(Session.currentUser.id);
                    //register push id
                    registerPush();
                    //stop loading
                    Session.stopLoading();
                    //return to caller
                    successHandler();
                }).error(function (data, status, headers, config) {
                    //error
                    console.log("Error calling /login for facebook login.");
                    //stop loading
                    Session.stopLoading();
                    //return to caller
                    failureHandler();
                });
            },
            loginLongTermToken: function (username, token, successHandler, failureHandler) {
                //start loading
                Session.startLoading();
                //do call
                $http({
                    method: 'GET',
                    url: Session.baseUrl + Session.servicePath + '/login',
                    headers: {
                        securityToken: Session.securityToken
                    },
                    params: {
                        logintype: Session.loginType,
                        username: username,
                        lttoken: token
                    }
                }).success(function (data, status, headers, config) {
                    //check exit code
                    switch (data.exitCode) {
                        case 0:
                            break;
                        case 26:
                            //stop loading
                            Session.stopLoading();
                            //popup error
                            Popup.error("user_not_found");
                            return;
                        case 27:
                            //stop loading
                            Session.stopLoading();
                            //popup error
                            Popup.error("wrong_password");
                            return;
                        case 28:
                            //stop loading
                            Session.stopLoading();
                            //popup error
                            Popup.error("token_expired");
                            $state.go('begin');
                            return;
                        default:
                            //stop loading
                            Session.stopLoading();
                            //popup error
                            Popup.error("user_not_found");
                            $state.go('begin');
                            return;
                    }
                    //set session user
                    var userValid = setUserDataToSession(headers, data);
                    //check if set was ok
                    if (!userValid) {
                        //stop loading
                        Session.stopLoading();
                        //popup error
                        Popup.error("user_invalid");
                        $state.go('begin');
                        return;
                    }
                    Analytics.trackAction("Login", "User" + Session.currentUser.id);
                    //track userid
                    Analytics.setUser(Session.currentUser.id);
                    //register push id
                    registerPush();
                    //stop loading
                    Session.stopLoading();
                    //return to caller
                    successHandler();
                }).error(function (data, status, headers, config) {
                    //error
                    console.log("Error calling /login for facebook login.");
                    //stop loading
                    Session.stopLoading();
                    //return to caller
                    failureHandler();
                });
            },
            signup: function (signupData, successHandler) {
                //start loading
                Session.startLoading();
                //do call
                $http({
                    method: 'POST',
                    url: Session.baseUrl + Session.servicePath + '/signup',
                    headers: {
                        securityToken: Session.securityToken
                    },
                    params: {
                        name: signupData.firstname,
                        lastname: signupData.lastname,
                        emailaddress: signupData.email,
                        password: signupData.password,
                        locale: I18n.getCurrentLanguage()
                    }
                }).success(function (data, status, headers, config) {
                    //check exit code
                    if (data.exitCode === 19) {
                        //stop loading
                        Session.stopLoading();
                        //popup error
                        Popup.error("user_exists");
                        return;
                    }
                    if (data.exitCode !== 0) {
                        //stop loading
                        Session.stopLoading();
                        //popup error
                        Popup.error("user_not_created");
                        return;
                    }
                    //set session user
                    var userValid = setUserDataToSession(headers, data);
                    //check if set was ok
                    if (!userValid) {
                        //stop loading
                        Session.stopLoading();
                        //popup error
                        Popup.error("user_invalid");
                        $state.go('begin');
                        return;
                    }
                    //track signup
                    Analytics.trackAction("Signup", "User" + Session.currentUser.id);
                    //track userid
                    Analytics.setUser(Session.currentUser.id);
                    //register push id
                    registerPush();
                    //stop loading
                    Session.stopLoading();
                    //return to caller
                    successHandler();
                }).error(function (data, status, headers, config) {
                    //error
                    console.log("Error calling /signup.");
                    //stop loading
                    Session.stopLoading();
                });
            },
            logout: function (successHandler) {
                //start loading
                Session.startLoading();
                //do call
                $http({
                    method: 'GET',
                    url: Session.baseUrl + Session.servicePath + '/logout',
                    headers: {
                        "SPRING_SECURITY_REMEMBER_ME_COOKIE": Session.currentUser.t,
                        "Content-Type": "application/json",
                        'Accept': 'application/json'
                    },
                    params: {
                        devicemodel: Session.sessionData.device.model,
                        deviceid: Session.sessionData.device.uuid,
                        deviceplatform: Session.sessionData.device.platform
                    }
                }).success(function (data, status, headers, config) {
                    Analytics.trackAction("Logout", "User" + Session.currentUser.id);
                    //log out session
                    Session.logout();
                    try {
                        localStorage.removeItem("un");
                        localStorage.removeItem("ltt");
                    } catch (error) {
                        console.log("NOTIBE: Error cleaning localStorage");
                    }
                    //stop loading
                    Session.stopLoading();
                    //return to caller
                    successHandler();
                }).error(function (data, status, headers, config) {
                    //error
                    console.log("Error calling /logout.");
                    //stop loading
                    Session.stopLoading();
                });
            },
            requestRecovery: function (emailaddress, successHandler, failureHandler) {
                //start loading
                Session.startLoading();
                //do call
                $http({
                    method: 'POST',
                    url: Session.baseUrl + Session.servicePath + '/password/recovery/request',
                    headers: {
                        securityToken: Session.securityToken
                    },
                    params: {
                        emailaddress: emailaddress,
                        locale: I18n.getCurrentLanguage()
                    }
                }).success(function (data, status, headers, config) {
                    Analytics.trackAction("Recover", "Requested::" + emailaddress);
                    //stop loading
                    Session.stopLoading();
                    //check exit code
                    if (data.exitCode !== 0) {
                        //return to caller
                        failureHandler();
                        return;
                    }
                    //return to caller
                    successHandler();
                }).error(function (data, status, headers, config) {
                    //error
                    console.log("Error calling /password/recovery/request for email.");
                    //stop loading
                    Session.stopLoading();
                    //return to caller
                    failureHandler();
                });
            },
            confirmRecovery: function (emailaddress, checkcode, newpassword, successHandler, failureHandler) {
                //start loading
                Session.startLoading();
                //do call
                $http({
                    method: 'POST',
                    url: Session.baseUrl + Session.servicePath + '/password/recovery/confirm',
                    headers: {
                        securityToken: Session.securityToken
                    },
                    params: {
                        emailaddress: emailaddress,
                        checkcode: checkcode,
                        newpassword: newpassword,
                        locale: I18n.getCurrentLanguage()
                    }
                }).success(function (data, status, headers, config) {
                    Analytics.trackAction("Recover", "Confirmed::" + emailaddress);
                    //stop loading
                    Session.stopLoading();
                    //check exit code
                    if (data.exitCode !== 0) {
                        //return to caller
                        failureHandler();
                        return;
                    }
                    //return to caller
                    successHandler();
                }).error(function (data, status, headers, config) {
                    //error
                    console.log("Error calling /password/recovery/confirm for email.");
                    //stop loading
                    Session.stopLoading();
                    //return to caller
                    failureHandler();
                });
            }
        };
    }]);