'use strict';
var pushService = angular.module('NotibeProject.services.push', []);
pushService.factory('Push', ['$cordovaPush', '$http', 'Session', 'Analytics',
    function ($cordovaPush, $http, Session, Analytics) {

        var pushAndroid = {
            "senderID": "113390557481",
            "ecb": "onNotificationGCM"
        };
        var pushIos = {
            "badge": "true",
            "sound": "true",
            "alert": "true",
            "ecb": "onNotificationAPN"
        };
        function addpushendpoint(pushendpointdata, successCallback) {
            $http({
                method: 'POST',
                url: Session.baseUrl + Session.servicePath + '/user/pushendpoint',
                headers: {
                    SPRING_SECURITY_REMEMBER_ME_COOKIE: Session.currentUser.t,
                    "Content-Type": "application/json",
                    'Accept': 'application/json'
                },
                params: {
                    devicemodel: Session.sessionData.device.model,
                    deviceid: Session.sessionData.device.uuid,
                    deviceplatform: Session.sessionData.device.platform,
                    pushid: pushendpointdata.pushid,
                    pushplatform: pushendpointdata.pushplatform
                }
            }).success(function (data, status, headers, config) {
                // return control to caller
                successCallback(data, headers);
            }).error(function (data, status, headers, config) {
                //error
            });
        }

        return {
            registerPush: function () {
                Analytics.trackAction("Push", "1::GetDeviceEndpoint::User" + Session.currentUser.id);
                try {
                    if (Session.sessionData.device.pushid === null) {
                        //REGISTER FOR NEW PUSHID
                        console.log("pushid never retrieved => calling $cordovaPush.register(...)");
                        Analytics.trackAction("Push", "2::NewDeviceEndpoint::User" + Session.currentUser.id);
                        //register push id
                        switch (Session.sessionData.device.platform) {
                            case 'Android':
                                try {
                                    console.log("try to register gcm");
                                    $cordovaPush.register(pushAndroid);
                                } catch (error) {
                                    console.log("error while registering to GCM");
                                }
                                break;
                            case 'iOS':
                                try {
                                    console.log("try to register apns");
                                    $cordovaPush.register(pushIos).then(
                                            function (apns_response) {
                                                console.log("received pushid " + apns_response);
                                                console.log("add push endpoint for apns pushid: " + apns_response);
                                                var pushendpointdata = {};
                                                if (apns_response.length === 64) {
                                                    console.log("apns_response IS the push id");
                                                    Analytics.trackAction("Push", "IOS::ApnsResponseIsToken::User" + Session.currentUser.id);
                                                    pushendpointdata.pushid = apns_response;
                                                    localStorage.setItem("pushid", pushendpointdata.pushid);
                                                } else {
                                                    console.log("apns_response should CONTAINS the push id");
                                                    try {
                                                        if (apns_response.deviceToken.length === 64) {
                                                            Analytics.trackAction("Push", "IOS::GoodDeviceToken::User" + Session.currentUser.id);
                                                            pushendpointdata.pushid = apns_response.deviceToken;
                                                            localStorage.setItem("pushid", pushendpointdata.pushid);
                                                        } else {
                                                            Analytics.trackAction("Push", "IOS::ERROR::InvalidDeviceToken::User" + Session.currentUser.id);
                                                        }
                                                    } catch (error) {
                                                        Analytics.trackAction("Push", "IOS::ERROR::NoDeviceTokenInResponse::User" + Session.currentUser.id);
                                                    }
                                                }
                                                if (pushendpointdata !== {}) {
                                                    if (Session.isDevelopment) {
                                                        console.log("DEV => use APNS_SANDBOX");
                                                        pushendpointdata.pushplatform = 'APNS_SANDBOX';
                                                    } else {
                                                        console.log("PROD => use APNS_SANDBOX");
                                                        pushendpointdata.pushplatform = 'APNS';
                                                    }
                                                    addpushendpoint(pushendpointdata, function (result, headers) {
                                                        //check for errors
                                                    });
                                                }
                                            },
                                            function (error) {
                                                console.log("error while registering to apns: " + error);
                                            }
                                    );
                                } catch (error) {
                                    console.log("error while registering to APNS: " + error);
                                }
                                break;
                            default:
                                console.log("push platform not supported");
                                break;
                        }
                    } else {
                        //CHECK ENDPOINT FOR PREVIOUS RETRIEVED PUSHID
                        Analytics.trackAction("Push", "2::OldDeviceEndpoint::User" + Session.currentUser.id);
                        console.log("pushid already retrieved => calling addpushendpoint");
                        switch (Session.sessionData.device.platform) {
                            case 'Android':
                                try {
                                    //register again to ALLOW ecb to be fired
                                    //WARNING!!! pushid will generally be the same of previous registration if never unregistered/invalidated
                                    //but can suddenly change => Backend should manage this situation => Verify
                                    $cordovaPush.register(pushAndroid);
                                } catch (error) {
                                    //nope
                                }
                                console.log("add push endpoint for gcm pushid: " + Session.sessionData.device.pushid);
                                var pushendpointdata = {};
                                pushendpointdata.pushid = Session.sessionData.device.pushid;
                                pushendpointdata.pushplatform = 'GCM';
                                addpushendpoint(pushendpointdata, function (result, headers) {
                                    //check for errors
                                });
                                break;
                            case 'iOS':
                                console.log("add push endpoint for apns pushid: " + Session.sessionData.device.pushid);
                                var pushendpointdata = {};
                                pushendpointdata.pushid = Session.sessionData.device.pushid;
                                if (Session.isDevelopment) {
                                    console.log("DEV => use APNS_SANDBOX");
                                    pushendpointdata.pushplatform = 'APNS_SANDBOX';
                                } else {
                                    console.log("PROD => use APNS_SANDBOX");
                                    pushendpointdata.pushplatform = 'APNS';
                                }
                                addpushendpoint(pushendpointdata, function (result, headers) {
                                    //check for errors
                                });
                                break;
                            default:
                                console.log("push platform not supported");
                                break;
                        }
                    }
                } catch (ex) {
                    console.log("Can't register for push");
                }
            },
            addpushendpoint: function (pushendpointdata, successCallback) {
                Analytics.trackAction("Push", "3::AddEndpointForUser::User" + Session.currentUser.id);
                console.log("executing addpushendpoint");
                addpushendpoint(pushendpointdata, successCallback);
            }
        };
    }]);