'use strict';
var subscriptionService = angular.module('NotibeProject.services.subscription', []);
subscriptionService.config(['$httpProvider', function ($httpProvider) {
        $httpProvider.defaults.withCredentials = false;
        $httpProvider.defaults.useXDomain = true;
    }]);
subscriptionService.factory('Subscription', ['$http', 'Session', 'Analytics', function ($http, Session, Analytics) {

        return {
            getContentCreators: function (page, successCallback) {
                Analytics.trackAction("Subscription", "GetContentCreators::User" + Session.currentUser.id);
                console.log("Using " + Session.currentUser.t);
                if (Session.sessionData.contentCreators.has_next) {
                    //start loading
                    Session.startLoading();
                    //do call
                    $http({
                        method: 'GET',
                        url: Session.baseUrl + Session.servicePath + '/cc/contentcreators',
                        headers: {
                            "SPRING_SECURITY_REMEMBER_ME_COOKIE": Session.currentUser.t,
                            "Content-Type": "application/json",
                            'Accept': 'application/json'
                        },
                        params: {
                            search: Session.sessionData.contentCreators.search,
                            page: page,
                            rows: 9
                        }
                    }).success(function (data, status, headers, config) {
                        //set contentCreatorPage
                        Session.sessionData.contentCreators.page = page;
                        Session.sessionData.contentCreators.has_next = data.resultMap.has_next;
                        //prepare grid list
                        var result = data.resultMap.result;
                        var list = [];
                        var i, j, temparray, chunk = 3;
                        //split result list into a list of smaller lists
                        for (i = 0, j = result.length; i < j; i += chunk) {
                            //get chunk and add it to final list
                            temparray = result.slice(i, i + chunk);
                            for (var k = 0; k < temparray.length; k++) {
                                //set subscribed property
                                temparray[k].subscribed = Session.currentUser.subscriptionsDictionary.hasOwnProperty(temparray[k].mediaName);
                            }
                            list.push(temparray);
                        }
                        Session.sessionData.contentCreators.list = Session.sessionData.contentCreators.list.concat(list);
                        //stop loading
                        Session.stopLoading();
                        //return to caller
                        successCallback();
                    }).error(function (data, status, headers, config) {
                        //error
                        console.log("Error GET /cc/contentcreators. " + data);
                        //stop loading
                        Session.stopLoading();
                    });
                } else {
                    //return to caller
                    successCallback();
                }
            },
            getStream: function (page, successCallback) {
                Analytics.trackAction("Subscription", "GetStream::User" + Session.currentUser.id);
                if (Session.sessionData.stream.has_next) {
                    //start loading
                    Session.startLoading();
                    //do call
                    $http({
                        method: 'GET',
                        url: Session.baseUrl + Session.servicePath + '/notify/stream',
                        headers: {
                            "SPRING_SECURITY_REMEMBER_ME_COOKIE": Session.currentUser.t,
                            "Content-Type": "application/json",
                            'Accept': 'application/json'
                        },
                        params: {
                            page: page,
                            rows: 5
                        }
                    }).success(function (data, status, headers, config) {
                        //set contentCreatorPage
                        Session.sessionData.stream.page = page;
                        Session.sessionData.stream.has_next = data.resultMap.has_next;
                        Session.sessionData.stream.list = Session.sessionData.stream.list.concat(data.resultMap.result);
                        //stop loading
                        Session.stopLoading();
                        //return to caller
                        successCallback();
                    }).error(function (data, status, headers, config) {
                        //error
                        console.log("Error GET /notify/stream.");
                        //stop loading
                        Session.stopLoading();
                    });
                } else {
                    //return to caller
                    successCallback();
                }
            },
            getNotificationsForMediaName: function (page, mediaName, successCallback) {
                Analytics.trackAction("Subscription", "GetNotifications::" + mediaName + "::User" + Session.currentUser.id);
                if (Session.sessionData.mediaNotifications[mediaName].has_next) {
                    //start loading
                    Session.startLoading();
                    //do call
                    $http({
                        method: 'GET',
                        url: Session.baseUrl + Session.servicePath + '/notify/notifications',
                        headers: {
                            "SPRING_SECURITY_REMEMBER_ME_COOKIE": Session.currentUser.t,
                            "Content-Type": "application/json",
                            'Accept': 'application/json'
                        },
                        params: {
                            page: page,
                            medianame: mediaName,
                            onlysent: true
                        }
                    }).success(function (data, status, headers, config) {
                        //set contentCreatorPage
                        Session.sessionData.mediaNotifications[mediaName].page = page;
                        Session.sessionData.mediaNotifications[mediaName].has_next = data.resultMap.has_next;
                        Session.sessionData.mediaNotifications[mediaName].list = Session.sessionData.mediaNotifications[mediaName].list.concat(data.resultMap.result);
                        //stop loading
                        Session.stopLoading();
                        //return to caller
                        successCallback();
                    }).error(function (data, status, headers, config) {
                        //error
                        console.log("Error GET /notify/notifications.");
                        //stop loading
                        Session.stopLoading();
                    });
                } else {
                    //return to caller
                    successCallback();
                }
            },
            subscribeContentCreator: function (cc, successCallback) {
                Analytics.trackAction("Subscription", "SubscribeContentCreator::" + cc.mediaName + "::User" + Session.currentUser.id);
                //start loading
                Session.startLoading();
                //do call
                $http({
                    method: 'POST',
                    url: Session.baseUrl + Session.servicePath + '/cc/subscribe',
                    headers: {
                        "SPRING_SECURITY_REMEMBER_ME_COOKIE": Session.currentUser.t,
                        "Content-Type": "application/json",
                        'Accept': 'application/json'
                    },
                    params: {
                        medianame: cc.mediaName
                    }
                }).success(function (data, status, headers, config) {
                    for (var i in data.resultMap.result) {
                        var subscription = data.resultMap.result[i];
                        Session.currentUser.subscriptionsDictionary[subscription.mediaPlatform.mediaName] = subscription;
                    }
                    //stop loading
                    Session.stopLoading();
                    //return to caller
                    successCallback();
                }).error(function (data, status, headers, config) {
                    //error
                    console.log("Error POST /cc/subscribe.");
                    //stop loading
                    Session.stopLoading();
                });
            },
            unsubscribeContentCreator: function (cc, successCallback) {
                Analytics.trackAction("Subscription", "UnsubscribeContentCreator::" + cc.mediaName + "::User" + Session.currentUser.id);
                //start loading
                Session.startLoading();
                //do call
                $http({
                    method: 'POST',
                    url: Session.baseUrl + Session.servicePath + '/cc/unsubscribe',
                    headers: {
                        "SPRING_SECURITY_REMEMBER_ME_COOKIE": Session.currentUser.t,
                        "Content-Type": "application/json",
                        'Accept': 'application/json'
                    },
                    params: {
                        medianame: cc.mediaName
                    }
                }).success(function (data, status, headers, config) {
                    delete Session.currentUser.subscriptionsDictionary[cc.mediaName];
                    //stop loading
                    Session.stopLoading();
                    //return to caller
                    successCallback();
                }).error(function (data, status, headers, config) {
                    //error
                    console.log("Error POST /cc/subscribe.");
                    //stop loading
                    Session.stopLoading();
                });
            },
//            insertNotification: function(notificationData, successCallback) {
//                //start loading
//                Session.startLoading();
//                //do call
//                $http({
//                    method: 'POST',
//                    url: Session.baseUrl + Session.servicePath + '/notify/notification',
//                    headers: {
//                        "SPRING_SECURITY_REMEMBER_ME_COOKIE": Session.currentUser.t,
//                        "Content-Type": "application/json",
//                        'Accept': 'application/json'
//                    },
//                    params: {
//                        medianame: notificationData.mediaName,
//                        priority: notificationData.priority,
//                        title: notificationData.title,
//                        text: notificationData.text,
//                        imageurl: notificationData.imageUrl,
//                        contenturl: notificationData.contentUrl,
//                        scheduleddate: notificationData.scheduledDate
//                    }
//                }).success(function(data, status, headers, config) {
//                    //stop loading
//                    Session.stopLoading();
//                    //return to caller
//                    successCallback();
//                }).error(function(data, status, headers, config) {
//                    //error
//                    console.log("Error POST /notify/notification.");
//                    //stop loading
//                    Session.stopLoading();
//                });
//            },
            toggleNormalPriority: function (mediaName, successCallback) {
                Analytics.trackAction("Subscription", "ToggleNormalPriority::" + mediaName + "::User" + Session.currentUser.id);
                //start loading
                Session.startLoading();
                //do call
                $http({
                    method: 'POST',
                    url: Session.baseUrl + Session.servicePath + '/cc/toggle/normalpriority',
                    headers: {
                        "SPRING_SECURITY_REMEMBER_ME_COOKIE": Session.currentUser.t,
                        "Content-Type": "application/json",
                        'Accept': 'application/json'
                    },
                    params: {
                        medianame: mediaName
                    }
                }).success(function (data, status, headers, config) {
                    //stop loading
                    Session.stopLoading();
                    //return to caller
                    successCallback();
                }).error(function (data, status, headers, config) {
                    //error
                    console.log("Error POST /cc/subscribe.");
                    //stop loading
                    Session.stopLoading();
                });
            }
        };
    }]);