'use strict';
var utilsService = angular.module('NotibeProject.services.utils', []);
utilsService.config(['$httpProvider', function ($httpProvider) {
        $httpProvider.defaults.withCredentials = false;
        $httpProvider.defaults.useXDomain = true;
    }]);
utilsService.factory('Utils', ['$http', 'I18n', 'Session', function ($http, I18n, Session) {
        return {
            getTimezones: function (successHandler) {
                //do call
                $http({
                    method: 'GET',
                    url: Session.baseUrl + Session.servicePath + '/timezones',
                    headers: {
                        "SPRING_SECURITY_REMEMBER_ME_COOKIE": Session.currentUser.t,
                        "Content-Type": "application/json",
                        'Accept': 'application/json'
                    },
                    params: {
                        language: I18n.getCurrentLanguage()
                    }
                }).success(function (data, status, headers, config) {
                    var timezones = data.resultMap.result;
                    //return to caller
                    successHandler(timezones);
                }).error(function (data, status, headers, config) {
                    //error
                    console.log("Error getting timezones.");
                });
            },
            getStatus: function (successHandler, failureHandler) {
                //do call
                $http({
                    method: 'GET',
                    url: Session.baseUrl + Session.servicePath + '/status',
                    timeout: 15000,
                    headers: {
                    },
                    params: {
                    }
                }).success(function (data, status, headers, config) {
                    //return to caller
                    successHandler();
                }).error(function (data, status, headers, config) {
                    //return to caller
                    failureHandler();
                });
            },
            isAndroidAppVersionValid: function (successHandler, failureHandler) {
                //do call
                $http({
                    method: 'GET',
                    url: Session.baseUrl + Session.servicePath + '/validate/ANDROID',
                    timeout: 30000,
                    headers: {
                        securityToken: Session.securityToken
                    },
                    params: {
                        version: Session.versionAndroid
                    }
                }).success(function (data, status, headers, config) {
                    console.log("app valid? " + data.resultMap.valid);
                    //return to caller
                    successHandler(data.resultMap.valid);
                }).error(function (data, status, headers, config) {
                    console.log("error in app validation:" + status);
                    //return to caller
                    failureHandler();
                });
            },
            isIOSAppVersionValid: function (successHandler, failureHandler) {
                //do call
                $http({
                    method: 'GET',
                    url: Session.baseUrl + Session.servicePath + '/validate/IOS',
                    timeout: 30000,
                    headers: {
                        securityToken: Session.securityToken
                    },
                    params: {
                        version: Session.versionIos
                    }
                }).success(function (data, status, headers, config) {
                    console.log("app valid? " + data.resultMap.valid);
                    //return to caller
                    successHandler(data.resultMap.valid);
                }).error(function (data, status, headers, config) {
                    console.log("error in app validation:" + status);
                    //return to caller
                    failureHandler();
                });
            }
        };
    }]);